==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Sketcher/Gui/SketchOrientationDialog.h <==
/***************************************************************************
 *   Copyright (c) 2011 Jrgen Riegel <juergen.riegel@web.de>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef SKETCHERGUI_SketchOrientationDialog_H
#define SKETCHERGUI_SketchOrientationDialog_H

#include <Base/Placement.h>

namespace SketcherGui {

class SketchOrientationDialog {
public:
    SketchOrientationDialog(void);
    ~SketchOrientationDialog();

    int exec();

    Base::Placement Pos;
    int             DirType;
   
};

}
#endif // SKETCHERGUI_SketchOrientationDialog_H

==> freecad_0.18~pre1+dfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Sketcher/Gui/SketchOrientationDialog.h <==
/***************************************************************************
 *   Copyright (c) 2011 Jürgen Riegel <juergen.riegel@web.de>              *
 *                                                                         *
 *   This file is part of the FreeCAD CAx development system.              *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Library General Public           *
 *   License as published by the Free Software Foundation; either          *
 *   version 2 of the License, or (at your option) any later version.      *
 *                                                                         *
 *   This library  is distributed in the hope that it will be useful,      *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Library General Public License for more details.                  *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this library; see the file COPYING.LIB. If not,    *
 *   write to the Free Software Foundation, Inc., 59 Temple Place,         *
 *   Suite 330, Boston, MA  02111-1307, USA                                *
 *                                                                         *
 ***************************************************************************/

#ifndef SKETCHERGUI_SketchOrientationDialog_H
#define SKETCHERGUI_SketchOrientationDialog_H

#include <Base/Placement.h>
#include <QDialog>

namespace SketcherGui {

class Ui_SketchOrientationDialog;
class SketcherGuiExport SketchOrientationDialog : public QDialog
{
    Q_OBJECT

public:
    SketchOrientationDialog(void);
    ~SketchOrientationDialog();

    Base::Placement Pos;
    int             DirType;

    void accept();

protected Q_SLOTS:
    void onPreview();

private:
    Ui_SketchOrientationDialog* ui;
};

}

#endif // SKETCHERGUI_SketchOrientationDialog_H
